@@ -1,10 +1,10 @@
 # Emilio Torres Manzanera
 # University of Oviedo
-# Time-stamp: <2013-05-02 Thu 09:27 emilio on emilio-despacho>
+# Time-stamp: <2014-02-27 jue 16:10 emilio on emilio-Satellite-P100>
 # =====================================================================
 
 pointscircunference <- function(x =0, y=0, diameter = 1, ratioxy=1, npoints = 16, alpha=  runif(1, 0, pi/2)){
-    require(Hmisc) # bezier
+    ##require(Hmisc) # bezier
     center <- c(x,y)
     r <- rep( diameter / 2, npoints )
     tt <- seq(alpha,2*pi + alpha,length.out = npoints)
